#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage			 : http://sourceforge.net/projects/tuxmath/
# source location	 : http://alioth.debian.org/frs/download.php/2684/tuxmath_w_fonts-1.7.2.tar.gz
# last revised       : 02.12.2009
# dep                : 

softname='tuxmath'
softversion='1.7.2'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/"$softname"_w_fonts"-$softversion""
srcpkg="$buildir/"$softname"_w_fonts"-$softversion.tar.gz""
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://alioth.debian.org/frs/download.php/2684/"$softname"_w_fonts-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
tuxmath: tuxmath - Math game for children
tuxmath:
tuxmath: tuxmath AKA Tux, of Math Command is an educational math tutorial game
tuxmath: starring Tux, the Linux Penguin. In this game, you are to prevent
tuxmath: comets from crashing by solving the equations to destroy them.
tuxmath:
tuxmath:
tuxmath:
tuxmath:
tuxmath: 
tuxmath:
EOF

# check if source is present
if [ -f $softname"_w_fonts"-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
 
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--localedir="/usr/share/locale" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# make icon
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -sf ../../../../tuxmath/images/icons/icon.png $softname.png

# make .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Tuxmath
Name[de]=Tuxmath
Exec=tuxmath
Comment=Tux, of Math Command
Comment[de]=Tux, of Math Command
Generic Name=Math Game
Generic Name[de]=Mathematik-Spiel
Terminal=false
Type=Application
Categories=Application;Game;
Icon=tuxmath
EOF

# add 'default' files
cd $src
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
    ABOUT-NLS AUTHORS COPYING ChangeLog INSTALL NEWS README \
    $dest/usr/doc/$softname-$softversion

cp -f $dest/usr/share/doc/tuxmath/* $dest/usr/doc/$softname-$softversion
rm -rf $dest/usr/share/doc/tuxmath
	
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "SDL_Pango,expat,fontconfig,freetype,glib2,libjpeg,\
libmad,libmikmod,libpng,libtiff,pango,sdl,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/tuxmath/source/build-tuxmath.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
